@@ -5,6 +5,9 @@ use lazy_static::lazy_static;
 
 use crate::{sleep_for, sys::is_online};
 
+pub const VERSION: &str = env!("CARGO_PKG_VERSION");
+pub const DESC: &str = env!("CARGO_PKG_DESCRIPTION");
+
 lazy_static! {
     pub static ref CACHE_DIR: Option<PathBuf> =
         BaseDirs::new().map(|dirs| dirs.cache_dir().to_owned().join("gitignore"));
