@@ -1,3 +1,4 @@
+mod cache;
 mod commands;
 mod lib;
 mod sys;
@@ -5,9 +6,7 @@ mod sys;
 #[macro_use]
 mod macros;
 
-mod cache;
-
-use commands::args::parse_args;
+use commands::args::ARGS;
 
 fn main() -> anyhow::Result<()> {
     if lib::CACHE_ENABLED.to_owned() {
@@ -29,7 +28,9 @@ fn main() -> anyhow::Result<()> {
         sleep_for!(3000);
     }
 
-    parse_args()?;
+    if let Some(cmd) = ARGS.command {
+        cmd.run()?;
+    }
 
     Ok(())
 }
